@@ -29,8 +29,8 @@
 #define DEBUG_KP_VIEW_MANAGER 0
 
 
-#include <kpViewManager.h>
-#include <kpViewManagerPrivate.h>
+#include "views/manager/kpViewManager.h"
+#include "kpViewManagerPrivate.h"
 
 #include <qapplication.h>
 #include <qlist.h>
@@ -38,13 +38,13 @@
 
 #include <kdebug.h>
 
-#include <kpDefs.h>
-#include <kpDocument.h>
-#include <kpMainWindow.h>
-#include <kpTempImage.h>
-#include <kpTextSelection.h>
-#include <kpTool.h>
-#include <kpView.h>
+#include "kpDefs.h"
+#include "document/kpDocument.h"
+#include "mainWindow/kpMainWindow.h"
+#include "layers/tempImage/kpTempImage.h"
+#include "layers/selections/text/kpTextSelection.h"
+#include "tools/kpTool.h"
+#include "views/kpView.h"
 
 //---------------------------------------------------------------------
 
@@ -362,4 +362,3 @@ void kpViewManager::setInputMethodEnabled (bool inputMethodEnabled)
 
 //---------------------------------------------------------------------
 
-#include <kpViewManager.moc>
